@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1995, 1998, 2000, 2002 Peter Miller;
+ *	Copyright (C) 1991-1995, 1998, 2000, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,7 @@ help_env(void)
 	 * The list of library directories to look in.
 	 */
 	string_list_constructor(&lib);
-	s = str_from_c(data_directory_get());
+	s = str_from_c(configured_datadir());
 	string_list_append_unique(&lib, s);
 	str_free(s);
 	cp = getenv("FHIST_MESSAGE_LIBRARY");
@@ -133,7 +133,7 @@ help_env(void)
 	string_list_destructor(&lib);
 	string_list_destructor(&lang);
 
-	s = str_from_c(manual_directory_get());
+	s = str_from_c(configured_mandir());
 	string_list_append_unique(&lib, s);
 	str_free(s);
 
