@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1998, 2002 Peter Miller;
+ *	Copyright (C) 1998, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,22 +24,29 @@
 #include <libdir.h>
 
 
-char *
-library_directory_get(void)
+const char *
+configured_libdir(void)
 {
     return LIBDIR;
 }
 
 
-char *
-data_directory_get(void)
+const char *
+configured_datadir(void)
 {
     return DATADIR;
 }
 
 
-char *
-manual_directory_get(void)
+const char *
+configured_mandir(void)
 {
     return MANDIR;
 }
+
+
+const char *
+configured_nlsdir(void)
+{
+    return NLSDIR;
+}
