@@ -1,6 +1,6 @@
 /*
  *	fhist - file history and comparison tools
- *	Copyright (C) 1991-1994, 1998-2002 Peter Miller;
+ *	Copyright (C) 1991-1994, 1998-2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	Derived from a work
@@ -26,7 +26,7 @@
  */
 
 #include <ac/ctype.h>
-#include <sys/types.h>
+#include <ac/sys/types.h>
 #include <ac/stdio.h>
 #include <ac/errno.h>
 #include <setjmp.h>
@@ -34,8 +34,7 @@
 #include <ac/stdlib.h>
 #include <ac/string.h>
 #include <ac/unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h> /* for mkdir */
+#include <ac/sys/stat.h> /* for mkdir */
 
 #include <arglex.h>
 #include <breaks.h>
@@ -661,6 +660,12 @@ main(int argc, char **argv)
 	    bad_argument(usage);
 	    /* NOTREACHED */
 
+	case arglex_token_number:
+	    /*
+	     * Modules names can look like numbers.
+	     * Fall through...
+	     */
+
 	case arglex_token_string:
 	    if (modulecount >= MAXMODULES)
 	    {
